
/*********************************************************\
*  BOOSTCONTROL defines                                   *
*  (C) 2003 [Marcell Gal, cell at x-dsl.hu                *
**********************************************************/
#ifndef BOOSTCONTROL_H
#define BOOSTCONTROL_H

#ifdef BOOSTCONTROL

#include "ve.h"
#include "helpers.h"
#include "pid.h"

struct boostctrl_t {
    uint16_t boost_target16; // 1/8 kPa unit
    uint8_t ref_dc;
    uint8_t dc_adjust;
};

union boost_union_t {
    struct boostctrl_t boost_simpledata;
    struct pid_t piddata;
};

EXTERN union boost_union_t boost_union;

#define boostcontrol_pid    boost_union.piddata
#define boost_data          boost_union.boost_simpledata

// called from mainloop:
#ifdef BOOSTGAUGE
void boostgauge_init(void);
void boostgauge_act(void);
#endif

void boostcontrol_init(void);

#define BOOSTCONTROL_PWM_PERIOD_8MS ((config.boost_conf & 0xF0)>>4)
#define BOOSTCONTROL_PWM_PERIOD_1MS(config_boost_conf) ((config_boost_conf & 0xF0) >>1 )

#define BOOSTCONTROL_FIXED_DUTY (config.boost_conf & 0x01)

#ifndef BOOSTACT_MINTIME
// don't actuate for shorter times than this (*4usec)
#define BOOSTACT_MINTIME	(15)
#endif // BOOSTACT_MINTIME

// SIMPLEBOOST defines:

// 1 kpa unit
#define BOOST_CONTROL_OVERSHOOT 9

// only for SIMPLEBOOST
#define boost_openloop              (config.boost_conf & 1)
#define boost_openloop_adc_chan     (config.boost_more & 0x0F)  

// refDC for boost  
#define boost_PWM_gear_depending     (config_ext.boostsw_conf&0x20)        //12x6[rpm,gear] refDC
#define boost_EGT_MAT_refDC_reducing (config_ext.boostsw_conf&0x40)    //reducing refDC when egt or IAT is to big

static inline uint8_t boost_tps_downscale(void)
{
	return interpol32( boost.tpstransfer_table, TPSTRANSFERTABLE_SIZE, engine_tps255() );
}

void ml_variable_boost(void);
//void ml_variable_boostalt(void);

#endif	// BOOSTCONTROL
#endif // BOOSTCONTROL_H

